/**
 * Utilities for generating unique and stable names.
 */
export declare class Names {
    /**
     * Generates a unique and stable name compatible DNS_LABEL from RFC-1123 from
     * a path.
     *
     * The generated name will:
     *  - contain at most 63 characters
     *  - contain only lowercase alphanumeric characters or ‘-’
     *  - start with an alphanumeric character
     *  - end with an alphanumeric character
     *
     * The generated name will have the form:
     *  <comp0>-<comp1>-..-<compN>-<short-hash>
     *
     * Where <comp> are the path components (assuming they are is separated by
     * "/").
     *
     * Note that if the total length is longer than 63 characters, we will trim
     * the first components since the last components usually encode more meaning.
     *
     * @link https://tools.ietf.org/html/rfc1123
     *
     * @param path a path to a node (components separated by "/")
     * @param maxLen maximum allowed length for name
     * @throws if any of the components do not adhere to naming constraints or
     * length.
     */
    static toDnsLabel(path: string, maxLen?: number): string;
    private constructor();
}
